@@ -36,7 +36,7 @@ our @C = (
       my $v            = $self->v;
       $v->{name}       = $name;
       $v->{controller} = $self->name;
-      $v->{_secret_from_json} = 
+      $v->{_secret_from_json} =
         'The JSON view will purposely omit this data, '.
         'because the $V{json}->profile template was written to '.
         'ignore the key, _secret_from_json.';
@@ -46,30 +46,57 @@ our @C = (
     }
   ),
 
+  # This controller shows you how $self->cookies handles
+  # both incoming AND outgoing cookies.
+  # - incoming cookies are stored in the $self->cookies hashref as strings
+  # - outgoing cookies are stored in the $self->cookies hashref as hashrefs
+  #     that can be fed to CGI::Cookie
+  C(
+    Cookie => [ '/cookies' ],
+    get => sub {
+      my ($self) = @_;
+      $self->v->{cookies} = [
+        map {
+          {
+            name  => $_,
+            value => $self->cookies->{$_},
+          }
+        } sort keys %{$self->cookies}
+      ];
+      $self->render('cookies');
+    },
+    post => sub {
+      my ($self) = @_;
+      my $input  = $self->input;
+      my $name   = $input->{name};
+      my $value  = $input->{value};
+      $self->cookies->{$name} = { -value => $value };
+      $self->redirect(R('Cookie'));
+    },
+  ),
+
   C(
     Count => [ '/@count' ],
-    # GET requests to the Count controller have the following properties:
-    # - They are sent to a different session queue.
-    # - The session queue is named "${session_id}.count".
-    # - The queue => { get => 'count' } is what made this happen.
-    # - Squatting::Mapper treats controllers with a queue attribute specially.
-    # - It will run GET requests in their own coroutine separate from the 
-    #   RESTful controllers.
-    # - This coroutine may handle many more HTTP requests.
+    # Requests to the Count controller run in a separate coroutine.
+    # - The (continuity => 1) tells Squatting::Mapper to take notice
+    #   of this controller and put requests to this controller in
+    #   a different "session queue".  In Continuity-speak, being in
+    #   a different "session queue" means you get your own coroutine.
+    continuity => 1,
+
     get => sub {
       my ($self) = @_;
       my $cr     = $self->cr;
       my $i      = 1;
+      # Infinite loops are allowed in Continuity controllers.
       while (1) {
-        # - In fact, this one won't ever return control back to Squatting.
+        # - Typically, you won't ever return control back to Squatting.
         # - You're in Continuity land, now.
         $cr->print($i++);
+        # $cr->next blocks until the next request comes in.
         $cr->next;
       }
     },
-    post => sub {
-    },
-    queue => { get => 'count' }
   ),
 
   C(
@@ -85,13 +112,13 @@ our @C = (
     get => sub {
       my ($self) = @_;
       my $v = $self->v = $self->env;
-      my $format = ($v->{REQUEST_PATH} eq '/env') 
-        ? 'html' 
-        : 'json';  
+      my $format = ($v->{REQUEST_PATH} eq '/env')
+        ? 'html'
+        : 'json';
       $self->render('env', $format);
       # This will use the generic json template called '_'
       #   if ($format eq 'json').
-      # The generic template, '_', is used 
+      # The generic template, '_', is used
       #   when no other template can be found.
     }
   ),
